/* MsJob.h - "end-to-end" data structures (known to Ms and the slave but */
/* not to Mama) */
/* Copyright (C) 1990 Andreas Gustafsson */

#ifndef _MsJob_h
#define _MsJob_h

#include "MsReal.h" /* for "netcomplex" declaration */

/* this is the part of a calculation request that is common to all */
/* requests generated for this exposure event */
struct static_job_info
{ short julia;		/* 0 for Mandelbrot, 1 for Julia set */
  short pad;		/* for alignment (and future expansion :-)) */
  netcomplex corner;	/* Corner C for Mandelbrot, C for Julia */
  netcomplex z0;	/* Z0=0 for Mandelbrot, corner Z for julia */
  netcomplex delta;	/* dC (Mandelbrot) / dZ (Julia) */
  long iteration_limit;
};

/* This is the information that changes from request to request */
/* This contains the same information as an XRectangle, but we don't want */
/* any X-specific information in the slave */
typedef struct
{ short x;
  short y;
  short height;
  short width;
} ms_rectangle;

/* this is what the .data field of a WhipMessage really looks like */
/* (but Mama doesn't know this) */
/* All the fields are stored in network byte order */
typedef struct
{ struct static_job_info j; /* corner, delta, iterations... */
  ms_rectangle s;
} ms_job;

#endif _MsJob_h
