/* MsP.h - private header for MandelSpawn popup widget */
/* Copyright (C) 1990 Andreas Gustafsson */

#ifndef _MsP_h
#define _MsP_h

#include <X11/CompositeP.h>
#include "Ms.h"
#include "MsReal.h"

#include "Mama.h"

#ifndef MIN
#define MIN(x,y) ((x) < (y) ? (x) : (y))
#endif
#ifndef MAX
#define MAX(x,y) ((x) > (y) ? (x) : (y))
#endif
#ifndef ABS
#define ABS(x) ((x) < 0 ? -(x) : (x))
#endif

/* data type for the rubberband box */
struct box
{ int x0,x1,y0,y1;
};

/* supported visual type / iteration count length combinations */
/* are obtained by ORing togeter one ITER_x and one DISP_x value */

#define ITER_BYTE		0
#define ITER_WORD		1

#define DISP_unknown		0
#define DISP_1plane32msb 	2  /* like a Sun monochrome display */
#define DISP_8plane		4  /* typical 8-plane framebuffer */
#define DISP_generic		6

/* widget instance structure */
typedef struct 
{ double center_x;		/* x coord. of view center */
  double center_y;		/* y coord. of view center */
  double xrange;		/* real axis interval */
  double yrange;		/* imaginary axis interval */
  unsigned long mi_count;	/* total no. of iterations done */
  struct static_job_info job;   /* information passed to the slave */
  GC box_gc;
  XPoint box_origin;
  XPoint box_corner;
  Bool box_exists;		/* the box is supposed to be visible */
  unsigned int box_hidden;	/* count of box hiding levels */
  unsigned int bytes_per_count; /* number of bytes in iteration count */
  unsigned int pixels_per_chunk; /* max. number of pixels in a chunk */
  XImage *linebuffer;
  unsigned int linebuffer_size; /* size of line buffer in bytes */
  MamaWidget mama;	      	/* our creator */
  unsigned chunks_out;		/* number of chunks being calculated */
  Bool center_box;		/* make box symmetric around origin */
  Cursor my_cursor;		/* cursor to use within Ms window */
  int type;			/* frame buffer type (for fast drawing) */
  unsigned configuration;	/* serial no. of current setup */
  Bool julia;			/* Julia set mode */
  double c_x;			/* c value for Julia set only */
  double c_y;
  Dimension chunk_height;	/* height of pixel block */
  Dimension chunk_width;	/* width of pixel block */
#ifdef MENU
  Widget menu;			/* the popup menu */
#endif
#ifdef LABEL
  Widget underflow_label;	/* the undeflow label widget */
  int underflow;		/* true if underflow label has been created */
#endif
} MsPart;

typedef struct _MsRec 
{ CorePart	core;
  CompositePart composite;
  MsPart	ms;
} MsRec;

/* Widget class structure */
typedef struct 
{ int dummy;
} MsClassPart;

typedef struct _MsClassRec 
{ CoreClassPart core_class;
  CompositeClassPart composite_class;
  MsClassPart ms;
} MsClassRec;

extern MsClassRec msClassRec;

/* this is what is stored in the client_data field in the chunk; */
/* basically this contains all the information that Ms needs needed to */
/* know what to do when a reply returns from a slave */
typedef struct
{ unsigned int configuration;
  XRectangle s;
} ms_client_info;

#endif /* _MsP_h */
